@@ -19,12 +19,13 @@ from rest_framework.views import APIView
 
 from drf_spectacular.authentication import OpenApiAuthenticationExtension
 from drf_spectacular.contrib import *  # noqa: F403, F401
+from drf_spectacular.drainage import get_override, has_override
 from drf_spectacular.extensions import OpenApiSerializerExtension, OpenApiSerializerFieldExtension
 from drf_spectacular.plumbing import (
     ComponentRegistry, ResolvedComponent, anyisinstance, append_meta, build_array_type,
     build_basic_type, build_choice_field, build_object_type, build_parameter_type, error,
-    follow_field_source, force_instance, get_doc, get_override, get_view_model, has_override,
-    is_basic_type, is_field, is_serializer, resolve_regex_path_parameter, safe_ref, warn,
+    follow_field_source, force_instance, get_doc, get_view_model, is_basic_type, is_field,
+    is_serializer, resolve_regex_path_parameter, safe_ref, warn,
 )
 from drf_spectacular.settings import spectacular_settings
 from drf_spectacular.types import OpenApiTypes
@@ -230,7 +231,7 @@ class AutoSchema(ViewInspector):
         perms = [p.__class__ for p in self.view.get_permissions()]
         if permissions.AllowAny in perms:
             auths.append({})
-        elif permissions.IsAuthenticatedOrReadOnly in perms and self.method not in ('PUT', 'PATCH', 'POST'):
+        elif permissions.IsAuthenticatedOrReadOnly in perms and self.method in permissions.SAFE_METHODS:
             auths.append({})
         return auths
 
@@ -689,13 +690,15 @@ class AutoSchema(ViewInspector):
 
     def _map_field_validators(self, field, schema):
         for v in field.validators:
-            # https://github.com/OAI/OpenAPI-Specification/blob/master/versions/3.0.3.md#data-types
             if isinstance(v, validators.EmailValidator):
                 schema['format'] = 'email'
-            if isinstance(v, validators.URLValidator):
+            elif isinstance(v, validators.URLValidator):
                 schema['format'] = 'uri'
-            if isinstance(v, validators.RegexValidator):
-                schema['pattern'] = v.regex.pattern
+            elif isinstance(v, validators.RegexValidator):
+                pattern = v.regex.pattern.encode('ascii', 'backslashreplace').decode()
+                pattern = pattern.replace(r'\x', r'\u00')  # unify escaping
+                pattern = pattern.replace(r'\Z', '$').replace(r'\A', '^')  # ECMA anchors
+                schema['pattern'] = pattern
             elif isinstance(v, validators.MaxLengthValidator):
                 attr_name = 'maxLength'
                 if isinstance(field, serializers.ListField):
@@ -929,6 +932,8 @@ class AutoSchema(ViewInspector):
             # though we do not support the serializer inlining feature.
             # https://drf-yasg.readthedocs.io/en/stable/custom_spec.html#serializer-meta-nested-class
             name = serializer.Meta.ref_name
+        elif isinstance(serializer, serializers.ListSerializer):
+            return self._get_serializer_name(serializer.child, direction)
         else:
             name = serializer.__class__.__name__
 
