@@ -186,17 +186,10 @@ urlpatterns = router.urls
 
 @pytest.mark.urls(__name__)
 def test_fields(no_warnings):
-    from django.core.validators import URLValidator
-
-    generator = SchemaGenerator()
-    schema = generator.get_schema(request=None, public=True)
-
-    # url pattern changed between django 3.0 and 3.1
-    field_url = schema['components']['schemas']['AllFields']['properties']['field_url']
-    assert field_url['pattern'] == URLValidator.regex.pattern
-    field_url['pattern'] = 'URL_REGEX_PATTERN'
-
-    assert_schema(schema, 'tests/test_fields.yml')
+    assert_schema(
+        SchemaGenerator().get_schema(request=None, public=True),
+        'tests/test_fields.yml'
+    )
 
 
 @pytest.mark.urls(__name__)
